Re-exports
pub use client::BuildError;pub use client::Client;pub use client::ClientBuilder;pub use client::HealthCheck;pub use client::QueueCapacity;pub use client::QueueHealth;pub use client::TransitionWorkerRole;pub use context::CallbackGuard;pub use context::JobContext;pub use dispatcher::QueueConfig;pub use dispatcher::RateLimit;pub use events::JobEvent;pub use events::RescueReason;pub use events::UntypedJobEvent;pub use executor::JobError;pub use executor::JobResult;pub use executor::Worker;pub use maintenance::RetentionPolicy;
Modules
- client
- context
- dispatcher
- events
- executor
- heartbeat
- maintenance
- metrics
- Backwards-compatible re-export of OpenTelemetry metric definitions.
Structs
- AwaMetrics
- Awa worker metrics backed by OpenTelemetry.
- Callback
Config - Configuration for CEL callback expressions.
- Enqueue
Request - Description of a follow-up job to enqueue when an
on_*_enqueuespec fires. Carries the follow-up’sJobArgsand theInsertOptsapplied to theINSERT. For the common “default opts” case, users can return theJobArgsvalue directly from their closure —EnqueueRequest::from(args)is invoked automatically. - Partitioned
Queue - A deterministic set of physical queues for one hot logical queue.
- Periodic
Job - A periodic job schedule definition.
- Periodic
JobBuilder - Builder for
PeriodicJob.
Enums
- Cron
Missed Fire Policy - How AWA handles cron fires missed because evaluation was delayed.
- Partitioned
Queue Error - Errors returned when constructing a
PartitionedQueue.