#[non_exhaustive]pub struct CallbackGuard {
pub id: Uuid,
}Expand description
Proof that this job registered an external callback in the database.
The public id can be sent to the external system. #[non_exhaustive]
keeps external callers from constructing this type directly.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: UuidImplementations