pub struct CallbackToken {
pub id: Uuid,
}Expand description
Token representing a registered callback for external webhook completion.
The id is a UUID that has been persisted to the database. Pass this ID
to the external system so it can call back to complete/fail/retry the job.
Fields
id: UuidAuto Trait Implementations
impl Freeze for CallbackToken
impl RefUnwindSafe for CallbackToken
impl Send for CallbackToken
impl Sync for CallbackToken
impl Unpin for CallbackToken
impl UnsafeUnpin for CallbackToken
impl UnwindSafe for CallbackToken