pub struct ClientBuilder { /* private fields */ }Expand description
Builder for the Awa worker client.
Implementations
Sourceimpl ClientBuilder
impl ClientBuilder
pub fn new(pool: PgPool) -> Self
Sourcepub fn queue(self, name: impl Into<String>, config: QueueConfig) -> Self
pub fn queue(self, name: impl Into<String>, config: QueueConfig) -> Self
Add a queue with its configuration.
Sourcepub fn register<T, F, Fut>(self, handler: F) -> Self
pub fn register<T, F, Fut>(self, handler: F) -> Self
Register a typed worker.
The worker handles jobs of type T where T: JobArgs + DeserializeOwned.
The handler function receives the deserialized args and job context.
Sourcepub fn register_worker(self, worker: impl Worker + 'static) -> Self
pub fn register_worker(self, worker: impl Worker + 'static) -> Self
Register a raw worker implementation.
Sourcepub fn state<T: Any + Send + Sync + Clone>(self, value: T) -> Self
pub fn state<T: Any + Send + Sync + Clone>(self, value: T) -> Self
Add shared state accessible via ctx.extract::<T>().
Sourcepub fn heartbeat_interval(self, interval: Duration) -> Self
pub fn heartbeat_interval(self, interval: Duration) -> Self
Set the heartbeat interval (default: 30s).
Sourcepub fn build(self) -> Result<Client, BuildError>
pub fn build(self) -> Result<Client, BuildError>
Build the client.